==> xffm-4.0.0.tar.gz: xffm-4.0.0/libs/misc.h <==
gboolean is_in_history(char *dbh_file,char *path2save);
gint on_key_press_history(GtkWidget * entry, GdkEventKey * event, gpointer data);
void count_selection(GtkTreeModel * treemodel, 
		GtkTreePath * treepath, 
		GtkTreeIter * iter, 
		gpointer data);
void get_history_list(GList **in_list,char *dbh_file,char *top);
void save_to_history(char *dbh_file,char *path2save);
void remove_from_history(char *dbh_file,char *path2save);

gchar *utf_2_local_string(char *t);
void process_pending_gtk();
gboolean find_root(GtkTreeView * treeview, int which);
const gchar *get_xffm_home(void);
void disable_diagnostics(void);
void enable_diagnostics(void);
gboolean is_number(char *c);
int get_fstab_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
void fork_function(void *data);
gchar * my_cut_utf_string(gchar *s);
gchar *my_utf_string(char *t);
void set_entry_tag(GtkTreeView * treeview, tree_entry_t * en, long long unsigned tama);

gboolean get_selectpath_iter(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_local_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_find_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_bookmark_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_trash_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_apps_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_network_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
#if defined(HAVE_GETMNTENT) || defined(HAVE_GETFSENT) || defined(HAVE_GETVFSENT)
int get_fstab_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
#endif
int erase_local_root(GtkTreeView * treeview);
int erase_find_root(GtkTreeView * treeview);
int erase_bookmark_root(GtkTreeView * treeview);
int erase_trash_root(GtkTreeView * treeview);
int erase_apps_root(GtkTreeView * treeview);
int erase_network_root(GtkTreeView * treeview);
#if defined(HAVE_GETMNTENT) || defined(HAVE_GETFSENT) || defined(HAVE_GETVFSENT)
int erase_fstab_root(GtkTreeView * treeview);
#endif

char *abreviate(char *path);
/*char *abreviateP(char *path);*/
void set_progress(GtkTreeView * treeview, int count, int total);
void set_progress_bytes(GtkTreeView * treeview, int count, int total);
void cursor_wait(GtkTreeView * treeview);

void cursor_reset(GtkTreeView * treeview);

void print_status(GtkTreeView * treeview, char *id, ...);
void print_status_tmp(GtkTreeView * treeview, GdkPixbuf * icono, ...);
void cleanup_tmpfiles(void);

void print_diagnostics(GtkTreeView * treeview, char *id, ...);
void print_diagnostics_tmp(GtkTreeView * treeview, GdkPixbuf * icono, ...);
void clear_diagnostics(GtkTreeView * treeview);
tree_details_t *get_tree_details(GtkTreeView * treeview);

void set_font(GtkTreeView * treeview, GtkTreeIter * iterator);

GtkTreeView *get_treeview(GtkWidget * widget);
GtkTreeView *get_selected_treeview(GtkWidget * widget);
void hideit(GtkWidget * parent, gchar * widget_name);
void showit(GtkWidget * parent, gchar * widget_name);
void hide_text(GtkWidget * parent);
void show_text(GtkWidget * parent);
void show_stop(GtkWidget * widget);
void hide_stop(GtkWidget * widget);

==> xffm4_4.0.6.orig.tar.gz: xffm-4.0.6/libs/misc.h <==
void set_processing_pending(void);
void unset_processing_pending(void);
gboolean processing_pending(void);
gboolean is_in_history(char *dbh_file,char *path2save);
gint on_key_press_history(GtkWidget * entry, GdkEventKey * event, gpointer data);
void count_selection(GtkTreeModel * treemodel, 
		GtkTreePath * treepath, 
		GtkTreeIter * iter, 
		gpointer data);
void get_history_list(GList **in_list,char *dbh_file,char *top);
void save_to_history(char *dbh_file,char *path2save);
void remove_from_history(char *dbh_file,char *path2save);

gchar *utf_2_local_string(char *t);
void process_pending_gtk();
gboolean find_root(GtkTreeView * treeview, int which);
const gchar *get_xffm_home(void);
void disable_diagnostics(void);
void enable_diagnostics(void);
gboolean is_number(char *c);
int get_fstab_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
void fork_function(void *data);
gchar * my_cut_utf_string(gchar *s);
gchar *my_utf_string(char *t);
void set_entry_tag(GtkTreeView * treeview, tree_entry_t * en, long long unsigned tama);

gboolean get_selectpath_iter(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_local_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_find_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_bookmark_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_trash_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_apps_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
int get_network_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
#if defined(HAVE_GETMNTENT) || defined(HAVE_GETFSENT) || defined(HAVE_GETVFSENT)
int get_fstab_root(GtkTreeView * treeview, GtkTreeIter * iter, tree_entry_t ** en);
#endif
int erase_local_root(GtkTreeView * treeview);
int erase_find_root(GtkTreeView * treeview);
int erase_bookmark_root(GtkTreeView * treeview);
int erase_trash_root(GtkTreeView * treeview);
int erase_apps_root(GtkTreeView * treeview);
int erase_network_root(GtkTreeView * treeview);
#if defined(HAVE_GETMNTENT) || defined(HAVE_GETFSENT) || defined(HAVE_GETVFSENT)
int erase_fstab_root(GtkTreeView * treeview);
#endif

char *abreviate(char *path);
/*char *abreviateP(char *path);*/
void set_progress(GtkTreeView * treeview, int count, int total);
void set_progress_bytes(GtkTreeView * treeview, int count, int total);
void cursor_wait(GtkTreeView * treeview);

void cursor_reset(GtkTreeView * treeview);

void print_status(GtkTreeView * treeview, char *id, ...);
void print_status_tmp(GtkTreeView * treeview, GdkPixbuf * icono, ...);
void cleanup_tmpfiles(void);

void print_diagnostics(GtkTreeView * treeview, char *id, ...);
void print_diagnostics_tmp(GtkTreeView * treeview, GdkPixbuf * icono, ...);
void clear_diagnostics(GtkTreeView * treeview);
tree_details_t *get_tree_details(GtkTreeView * treeview);

void set_font(GtkTreeView * treeview, GtkTreeIter * iterator);

GtkTreeView *get_treeview(GtkWidget * widget);
GtkTreeView *get_selected_treeview(GtkWidget * widget);
void hideit(GtkWidget * parent, gchar * widget_name);
void showit(GtkWidget * parent, gchar * widget_name);
void hide_text(GtkWidget * parent);
void show_text(GtkWidget * parent);
void show_stop(GtkWidget * widget);
void hide_stop(GtkWidget * widget);
